elist.median: Calculate Probe Medians of ExpressionSet

Description Usage Arguments Value Author(s) Examples

View source: R/elist_median.R

Description

This function takes an EList, calculates a score from the quality flags and removes measurements with lower scores than the minimum score for that probe. If there are multiple measurements for the same probe the median is calculated.

Usage

1

Arguments

data

an EList

Value

an Elist

Author(s)

This function is based on a function of Kristin Reiche

Examples

1
No example yet

anschue/toxprofileR documentation built on Nov. 2, 2019, 1:55 p.m.