Description Usage Arguments Value Author(s) Examples
This function takes an EList, calculates a score from the quality flags and removes measurements with lower scores than the minimum score for that probe. If there are multiple measurements for the same probe the median is calculated.
1 |
data |
an EList |
an Elist
This function is based on a function of Kristin Reiche
1 | No example yet
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.